@@ -4,7 +4,7 @@ test_that("install_acro installs 'acro' in the specified environment", {
   test_envname <- "test-acro-env"
 
   # Run the install_acro function
-  install_acro(envname = test_envname)
+  install_venv(envname = test_envname)
 
   # Check if 'acro' is installed in the test environment
   is_installed <- reticulate::py_module_available("acro")
